﻿********************************************************************************
*              Synatx -  Data prepation - MASTER DO-FILE   						*
*  The Productivity Effects of Worker Mobility Between Heterogeneous Firms      * 
*               Stockinger / Wolf (August 2018)       	                        *
********************************************************************************

set more off, perm
clear
global date  "xxxx"

capture log close
	
/* Globals: paths */
do "..../0_globale_pfade.do"

/*Abbreviations:
BeH = Employment History
EP = IAB Establishment Panel
BHP = Establishment History Panel
IEB = Integrated Employment Biographies
FDZ = Research Data Centre of IAB
DIM = Social security data and IT department of IAB */


/*****************************************************************/	
/* Wanted: Linked employer-employee panel for establishments surveyed in the IAB Establishment Panel between 2003 and 2011, with employment spells between 1999 and 2010 of all employees
(we use only a subset of these establishments, those with at least 3 consecutive obs. btw. 2003 and 2011 (for System GMM), with nonmissing values in key variables, etc.) */
/*****************************************************************/	


/*****************************************************************/	
/* (0) Input (given)											*/
/*****************************************************************/	
/*
BeH version 09.01 (entire employment history (empl. liable to social security), supplied by DIM)

$fdz_path_bp9312\iabbp_`i', where `i' = 1999-2011
(IAB Establishment Panel, waves 1999-2011, supplied by FDZ (see http://doku.iab.de/fdz/reporte/2018/DR_01-18_EN.pdf))
(Years 1999-2001 are needed for lagged variables and construction of capital stock using the PIM method;
year 2011 is needed because we examine the lagged effect of worker inflows in 2002-2010 on productivity in 2003-2011)

$bhp7510_path/bhp_7510_m06_bst_v1_`i', where `i' = 1999-2010 (supplied by FDZ)
(Establishment History Panel, 1999-2010 (years 1999-2001 are needed for lagged variables)

$bhp7510_path/bhp_7510_m06_aus_v1 (supplied by FDZ)
(see http://doku.iab.de/fdz/reporte/2010/MR_06-10-EN.pdf )

$bhp7510_path\WZ_BHP_7510_w73_w93_v1 (supplied by FDZ)
(industry codes for all establishments, consistent over time, i.e. across classification changes)

$data_files_path/ieb_`i', where `i' = 2002-2010 (supplied by DIM)
(Integrated Employment Biographies for all employees of the selected Establishment Panel establishments)

$data_files_path/Bet_Firm_IDs_`j', where j = 2001-2009
Estimated company IDs for each establishment (obtained as documented in http://doku.iab.de/fdz/reporte/2014/MR_05-14_EN.pdf )
(supplied by DIM)

CHK_perseff_*_2002-2009 (* = f for female or m for male)
Person fixed wage effects as computed and supplied by Card, Heining and Kline (2015) (http://doku.iab.de/fdz/reporte/2015/MR_06-15_EN.pdf)
available directly from FDZ upon request

$project_path/Sonstige_Daten/AMR_Kreise_2011_Kosfeld_Werner_bearbeitet (mapping of districts (NUTS 3 regions) to labor market regions as defined by Kosfeld and Werner, 2012)
(https://link.springer.com/article/10.1007/s13147-011-0137-8)

$project_path/Sonstige_Daten/Deflation_1975_2010 (deflation factor based on CPI)
(https://www.destatis.de/DE/ZahlenFakten/GesamtwirtschaftUmwelt/Preise/Verbraucherpreisindizes/Tabellen_/VerbraucherpreiseKategorien.html, 28.04.2014)

$data_files_path/orig_bp_betriebe_idnum_alle (supplied by DIM) 
List of establishment identifiers of all establishments surveyed in the EP between 2003 and 2011 (variables betnr, as used in the IEB and BHP, and idnum, as used in the EP)

$data_files_path/orig_bp_betriebe_betnr_alle (supplied by DIM) 
List of establishment identifiers of all establishments surveyed in the EP between 2003 and 2011 (variable betnr, as used in the IEB and BHP)
*/



/* ******************************************************** */
/* (1) Preliminary steps                                */
/* ******************************************************** */
			
// (a) Generation of time-consistent industry codes in the face of classification changes  (see http://doku.iab.de/fdz/reporte/2011/MR_05-11_EN.pdf)

do "$do_files_path/Vorarbeiten/1a_vorarbeiten_wz03_bhp"
			*in:   $bhp7510_path/WZ_BHP_7510_w73_w93_v1		(Step 0)
			*out:  $data_files_path/w93_bhp_end_jahr

// (b) Clean establishment median wage of industry fixed effects (as in Stoyanov/Zubanov)
do "$do_files_path/Vorarbeiten/1b_te_med_bereinigen.do"
			*in:   $bhp7510_path\bhp_7510_m06_bst_v1_`i'	(Step 0)
			*      $data_files_path/w93_bhp_end_jahr  		(Step 1a)
			*out:  $data_files_path/te_ber_`i'
		
// (c) Identifying exits of establishments - necessary when estimating Olley-Pakes (see http://doku.iab.de/fdz/reporte/2010/MR_06-10-EN.pdf) */			
 do "$do_files_path/Vorarbeiten/1c_vorarbeiten_exit_olleypakes.do"	
			*in:   $bhp7510_path/bhp_7510_m06_aus_v1		(Step 0)
			*out:  $data_files_path/exits_bhp
				
			
/* ****************************************************** */
/* (2) Identify relevant establishments surveyed in the IAB Establishment Panel between 2003 and 2011 */
/* ********************************************************** */

do "$do_files_path/2_list_ep_establishments.do" 
			*in: "$data_files_path/orig_bp_betriebe_betnr_alle" 	(Step 0) 
			*    "$data_files_path/w93_bhp_end_jahr" 				(Step 1a)
			*     $data_files_path/bhp_7510_m06_bst_v1_`i' 			(Step 0)
	        *out: $data_files_path/bp_betriebe_vergew_mindestgröße
	
	
	
/* ************************************************************** */
/* (3) Establishment Panel data preparation                        */
/* ************************************************************** */
    
/*Note: This EP data preparation (Step a - e is supplied by FDZ as a standard procedure which we use for convenience.
  Specific adjustments for this study are only made in steps f and g */
do "$do_files_path/3a_syntax_panel_1993_1998.do"	// Basic recoding and renaming of variables
do "$do_files_path/3b_syntax_panel_1999_2012.do"	// Basic recoding and renaming of variables
do "$do_files_path/3c_Zusammenspielen.do"			// Append waves (years)
do "$do_files_path/3d_Variablen_und_Wertelabels.do"	// Variable and value labels (German)
do "$do_files_path/3e_Werteuebertragung.do"			// Imputation of specific variables (regarding workplace organisation, irrelevant for our study)
do "$do_files_path/3f_rel_Var_behalten.do"			// Keep relevant variables
do "$do_files_path/3g_betriebspanel_bereinigung.do"	// Keep relevant years, recode years (e.g. 2003 -> 2002) because most variables refer to the previous year 
	
			*in:  $fdz_path_bp9312\iabbp_`i'		(Step 0, see http://doku.iab.de/fdz/reporte/2018/DR_01-18_EN.pdf)
			*out: $data_files_path/betriebspanel

			
			
/* ******************************************************* */
/* (4) Generate establishment-level control variables      */
/* ******************************************************* */

//(a) From BHP
do "$do_files_path/4a_kontrollvariablen_betriebsebene_bhp"
			*in:     $data_files_path/bp_betriebe_vergew_mindestgröße 						(Step 2)
			*        $bhp7510_path/bhp_7510_m06_bst_v1_`i'   								(Step 0)
			*        $data_files_path/w93_bhp_end_jahr   									(Step 1a)
			*        $project_path/Sonstige_Daten/AMR_Kreise_2011_Kosfeld_Werner_bearbeitet	(Step 0)
			*        $data_files_path/exits_bhp  											(Step 1c)
			*out:    $data_files_path/kontrollvariablen_bhp_2002_2010  

// (b) From EP
do "$do_files_path/4b_kontrollvariablen_betriebsebene_betriebspanel"
			*in:     $data_files_path/bp_betriebe_vergew_mindestgröße	(Step 2)
			*        $data_files_path/betriebspanel             		(Step 3)
			*        $data_files_path/orig_bp_betriebe_idnum_alle   	(Step 0) 
			*out:    $data_files_path/kontrollvariablen_betriebspanel_2002_2010

// (c) Capital stock (from EP, using PIM method (cf. Mueller, Steffen (2008), "Capital Stock Approximation Using Firm Level Panel Data", Jahrbücher für Nationalökonomie und Statistik, 228(4)))
do "$do_files_path/4c_kontrollvariablen_betriebsebene_betriebspanel_Kapital"
			*in: 	$data_files_path/bp_betriebe_vergew_mindestgröße	(Step 2)
			*		$data_files_path/w93_bhp_end_jahr  					(Step 1a)
			*		$data_files_path/betriebspanel 						(Step 3)
			*       $data_files_path/orig_bp_betriebe_idnum_alle    	(Step 0)
			*out: 	$data_files_path/kontrollvariablen_betriebspanel_Kapitalstock_2002_2010


/* (d) Combine establishment-level control variables */
do "$do_files_path/4d_kontrollvariablen_betriebsebene"
			*in: 	$data_files_path/kontrollvariablen_betriebspanel_2002_2010 				(Step 4a) 
			*       $data_files_path/kontrollvariablen_betriebspanel_Kapitalstock_2002_2010	(Step 4c)	
			*       $data_files_path/kontrollvariablen_bhp_2002_2010  						(Step 4b)
			*out: 	$data_files_path/kontrollvariablen_betriebsebene	

			
/* ************************************************************************************ */
/* (5) Further establishment-level cleaning steps like e.g. establishment age, missing information   */
/* ************************************************************************************* */

do "$do_files_path/5_sample_ep_establishments.do"
			*in: 	$data_files_path/kontrollvariablen_betriebsebene (Step 4d)
			*out: 	$data_files_path/sample_ep_ende       
	
/* ************************************************************** */
/* (6) Identify relevant worker Inflows to sampled establishments   */
/* *************************************************************** */

 do "$do_files_path/6_inflows.do"
			*in:  	$data_files_path/ieb_`i' where `i' = 2002-2010	(Step 0)
			*	  	$data_files_path/sample_ep_end 					(Step 5)
			*out: 	$data_files_path/neuzugänge_betriebswechsler_clean_t1_`i' where `i' = 2002-2010

	
	
/* *********************************************************************** */
/* (7) Identify and delete spurious worker flows  --> (1) between establishments belonging to the same company and (2) due to establishment ID-change or takeover of sending establishments   +7                                     */
/* *********************************************************************** */
	
 do "$do_files_path/7_spurious_inflows.do"
			*in: 	$data_files_path/neuzugänge_betriebswechsler_clean_t1_`i'	(Step 6)
			*		$data_files_path/Bet_Firm_IDs_`j'    						(Step 0)
			*		$bhp7510_path/bhp_7510_m06_aus_v1    						(Step 0)
			*out: 	$data_files_path/neuzugänge_betriebswechsler_clean_bad_t1_`i'

			
/* *********************************************************************** */
/* (8) Merge CHK person fixed effects				                       */
/* *********************************************************************** */

  do "$do_files_path/8_CHK_effects.do"
  
			*in:	$data_files_path/neuzugänge_betriebswechsler_clean_bad_t1_`i' 		(Step 7) 
			* 		$path_project\Sonstige_Daten\CHK_Effekte\CHK_perseff_m_2002-2009	(Step 0) 
			*		$path_project\Sonstige_Daten\CHK_Effekte\CHK_perseff_f_2002-2009 	(Step 0)
			* 		$path_project\Sonstige_Daten\CHK_Effekte\CHK_perseff_m_1996-2002 	(Step 0)
			*		$path_project\Sonstige_Daten\CHK_Effekte\CHK_perseff_f_1996-2002 	(Step 0)
			*out:	$data_files_path/neuzugänge_betriebswechsler_clean_bad_chk_t1_`i'


			
/* ************************************************************************ */
/* (8.1) Obtain the input for steps 9a and 9b (Establishment fixed wage effects and 
individual wage positions from estimation of equation B1, Appendix B) */
/* ************************************************************************ */
			
 do	"$do_files_path/8_1_Ziehen_betnrs_für_BeH_2.do"
			*in: 	$data_files_path/neuzugänge_betriebswechsler_clean_t1_`i'	(Step 6)
			*out:	$data/betnrs_send_hire_2_20151002

 /* The following 3 dofiles had to be run by DIM in Nov/Dec 2015 because they use the entire BeH (population of employment liable to soc. sec. in Germany),
 to which DIM has better access and more computation capacity  */
  
 do "$do_files_path/8_2_Master_103612.do" // draws relevant establishments and workers from the BeH and calls the following do-file:
	* $do_files_path/8_3_Betriebseffekt_ind_Lohneffekt_1127.do	// runs the wage regression (equation B1) and calls the following do-file:
	* $do_files_path/8_4_Betriebseffekt_Lohnimp.do		 		// runs a wage imputation for censored wages
			*in:	BeH version 09.01														(Step 0)
			*		$project_path/Sonstige_Daten/AMR_Kreise_2011_Kosfeld_Werner_bearbeitet	(Step 0)
			*		$data/betnrs_send_hire_2_20151002										(Step 8.1)
			*out:	$data_files_path/beh_20151201/Indiv_Lohneffekte_`i'
			*		$data_files_path/beh_20151201/Betriebseffekte_`k'



/* ************************************************************************ */
/* (9) Merge establishment fixed wage effect and individual wage position (in sending and receiving establishment) and delete "bad" inflows  */
/* *************************************************************************** */

/* (a) Merge establishment fixed wage effect */

 do "$do_files_path/9a_betriebseffekt.do"
			 *in:	$data_files_path/beh_20151201/Betriebseffekte_`k' 					(Step 8.1)
			 *		$data_files_path/neuzugänge_betriebswechsler_clean_bad_chk_t1_`i' 	(Step 8)
			 *out:	$data_files_path/Betriebseff_Neu_`k'_betnr 
			 *		$data_files_path/neuzugänge_betriebswechsler_clean_bad_chk_fe_t1_`i' 
	  
/* (b) Merge worker inflows' sending-establishment wage position */  

 do "$do_files_path/9b_lohnposition.do"
		  *in:    $data_files_path/beh_20151201/Indiv_Lohneffekte_`i'					(Step 8.1)	
		  *	      $path_project/Sonstige_Daten/Deflation_1975_2010						(Step 0)
		  *       $data_files_path/neuzugänge_betriebswechsler_clean_bad_chk_fe_t1_`i' 	(Step 9a)
		  *out:   $data_files_path/neuzugänge_betriebswechsler_clean_bad_chk_fe_wagepos_t1_`i'
				  
		  
/* ************************************************************************ */
/* (10) Defining SPs and Non-SP Inflows                                   */
/* *************************************************************************** */
do "$do_files_path/10_individual_inflows_final.do"
	     *in:	 $data_files_path/neuzugänge_betriebswechsler_clean_bad_chk_fe_wagepos_t1_`i' 	(Step 9b)
		 *       $data_files_path/te_ber_`i'													(Step 1b)
		 *out: 	 $data_files_path/individual_inflows_descriptives 
		 

/* ************************************************************************ */
/* (11) Aggregate inflow information to the establishment level                */
/* *************************************************************************** */
do  "$do_files_path/11_aggregation_inflows.do"
         *in: 	$data_files_path/individual_inflows_descriptives (Step 10)
		 *out:  $data_files_path/agg_inflows_estimation

/* *************************************************************************** */
/* (12) merge of establishment-level data sets                   */
/* **************************************************************************** */

/*	(a) Preparatory steps --> indicator establishment without fixed wage effect */
do "$do_files_path/12a_betriebe_ohne_fe.do"
  		*in: 	$data_files_path/Betriebseff_Neu_`k'_betnr 	(Step 9a)
		*       $data_files_path/sample_ep_ende 			(Step 5)
		*out: 	$data_files_path/BP_ohne_FE_Betriebseffekt_t1


do "$do_files_path/12b_merge_master.do"
		*in: 	$data_files_path/kontrollvariablen_betriebsebene 	(Step 4d)
		*		$data_files_path/sample_ep_ende  					(Step 5)
		*		$data_files_path/agg_inflows_estimation  			(Step 11)
		*		$data_files_path/BP_ohne_FE_Betriebseffekt_t1  		(Step 12a)
		*out: 	$data_files_papth/datensatz_t`zeit'

	
save $data_files_path/datensatz_t1_ende, replace



cap log close

exit, STATA



