cap log close
log using "$log_files_path/aggregation_inflows_vorbereitung_appendjahre_$date", replace

cd $path_project

/**************************************** */
/* (1) Inflows from all years */
/* ****************************************** */
forval i = 2002/2010{
use $data_files_path/neuzugänge_betriebswechsler_clean_bad_chk_fe_wagepos_t1_`i', clear
global variablen berufstell_beschvor wohn_kr_beschvor betnr_vor_beschspell ///
 idnum_beschvor  beruf_num_beschvor arb_kr_beschvor
foreach var of global variablen{
rename `var'_`i'0101 `var'
}
drop jahr





rename betnr_vor_beschspell betnr_beschvor

qui save $data_files_path/temp_t1_`i', replace
}


use $data_files_path/temp_t1_2002, clear
gen jahr = 2002
forvalues i = 2003/2010{
qui append using $data_files_path/temp_t1_`i'
qui replace jahr = `i' if jahr == .
}
save $data_files_path/neuzugänge_betriebswechsler_clean_2_chk_fe_wagepos_t1, replace


forvalues i = 2002/2010{
erase $data_files_path/temp_t1_`i'.dta
}


/* *********************************************************************** */
/* (2) Prepare several variables related to inflows (industry, region, male, age) 	*/
/* ************************************************************************ */
use $data_files_path/neuzugänge_betriebswechsler_clean_2_chk_fe_wagepos_t1 , clear

   
 /* 1. Age */
 
gen geb_jahr = year(geb_dat)
gen alter_inf = jahr - geb_jahr
drop geb_jahr
drop geb_dat
label var alter "age"


/* 2. Gender */
gen byte male = sex_id == 1
drop sex_id
label var male "dummy: 1 male 0 female"


/* 3. Qualification */

gen byte bild_uni_fh_inf = ausbildung_num == 5 |ausbildung_num == 6
drop ausbildung_num



drop p_pers_effekt* wohn_kr arb_kr erw_stat_num beruf_num idnum_beschvor ///
 beruf_num_beschvor arb_kr_beschvor wohn_kr_beschvor  ///



/* *********************************************************************** */
/* (3) Drop if establishment fixed wage effect is missing	*/
/* ************************************************************************ */

gen byte fe_rec_mis = fe_betrieb_rec == .
gen byte fe_send_mis = fe_betrieb_send == .
gen byte fe_send_rec_mis = fe_rec_mis == 1 | fe_send_mis == 1


drop if fe_send_rec_mis == 1
drop fe_rec_mis fe_send_mis fe_send_rec_mis 


 /* *********************************************************************** */
 /* (4) Indicate Non-/SPs    */
 /* ************************************************************************** */
/* (a) indicate Non-/SPs according to estab. fixed effect */

gen byte inf_sp = fe_betrieb_send>fe_betrieb_rec
label var inf_sp "Inflow spillover potential"

gen byte inf_nsp = fe_betrieb_send<= fe_betrieb_rec
label var inf_nsp "Inflow non spillover potential"

/* (b) indicate Non-/SPs according to estab. median wage */

ren jahr year
gen jahr=year - 1 - 1   //  2000-2008 


/* Merge median wage cleared of industry fixed effects */

forv i = 2000/2008 {
merge m:1 betnr jahr using  $data_files_path/te_ber_`i', keepusing(te_ber) update
drop if _merge==2
drop _merge
}

ren te_ber te_ber_hire
gen te_ber=.

ren betnr betnr_hire
ren betnr_beschvor betnr


forv i = 2000/2008 {
merge m:1 betnr jahr using  $data_files_path/te_ber_`i', keepusing(te_ber) update
drop if _merge==2
drop _merge
}

ren te_ber te_ber_send

ren  betnr  betnr_beschvor 
ren betnr_hire betnr 

drop jahr
ren year jahr
drop betnr_beschvor 

 /* indiciate SP / NSP */
gen byte inf_sp_te2 = te_ber_send > te_ber_hire
gen byte inf_nsp_te2 = te_ber_send <= te_ber_hire



/* (c) Individual wage position in sending/receiving estab. and CHK_Effekt SP and NSP */
rename fe_indiv_send resid_inf
gen resid_inf_sp = resid_inf if inf_sp == 1
gen resid_inf_nsp = resid_inf if inf_nsp == 1
gen resid_inf_sp_te2 = resid_inf if inf_sp_te2 == 1
gen resid_inf_nsp_te2 = resid_inf if inf_sp_te2 == 0

rename fe_indiv_hire res_inf_hire
gen resid_hire_sp = res_inf_hire if inf_sp == 1
gen resid_hire_nsp = res_inf_hire if inf_nsp == 1
gen resid_hire_sp_te2 = res_inf_hire if inf_sp_te2 == 1
gen resid_hire_nsp_te2 = res_inf_hire if inf_sp_te2 == 0

gen pers_effekt_inf_sp = pers_effekt if inf_sp == 1
gen pers_effekt_inf_nsp = pers_effekt if inf_sp == 0

gen pers_effekt_inf_sp_te2 = pers_effekt if inf_sp_te2 == 1
gen pers_effekt_inf_nsp_te2 = pers_effekt if inf_sp_te2 == 0

rename pers_effekt pers_effekt_inf

 /* *********************************************************************** */
 /* (5) Individual Inflows Dataset for Descriptives    */
 /* ************************************************************************** */

 save "$data_files_path/individual_inflows_descriptives", replace
 
log close
