


cap log close
log using "$log_files_path/capital_approx_Mueller_$date", replace


****************************************************************************
* Capital Stock Approximation with the IAB Establishment Panel
* When applying the method please refer to:
* Mueller, Steffen (2008), "Capital Stock Approximation Using Firm Level
* Panel Data", Jahrbücher für Nationalökonomie und Statistik, 228(4)
* The paper may help you in understanding this program.
****************************************************************************

****************************************************************************
* Prerequisites:
* IAB establishment data as a panel data set
* All variables that refer to the previous year (e.g. investments) but are asked
* in the current year have to be moved to the previous year. 
* KW: This was done already in B_Betriebspanel_Aufbereitung/7_betriebspanel_bereinigung.do -- STIMMT DAS?
* Please make sure that the industry codes for all years of panel participation
* are translated into the wz93 industry codes that are used from year 2000 on.

* BS: LUCKILY, AT THE 2-DIGIT LEVEL WHICH IS USED HERE, WZ03 IS EXACTLY THE SAME AS WZ93

****************************************************************************

****************************************************************************
* This program follows paper and Section 3 above and is organized as follows:
* 1. import the average economic lives of industry capital stock (ND) from the
* national accounts - AVAILABLE FROM DESTATIS UPON REQUEST (?)
* 2. generate economic lives for net investments with information from the German
* federal statistical office - COMPOSITION OF CAPITAL STOCK (STRUCTURES & EQUIPMENT) FOR INDUSTRIES; FACHSERIE 18 REIHE 1.3 (AB 2005 1.4) 
* 3. multiply the replacement investment for each firm-year observation with the ND
* 4. create a starting value for perpetual inventory and perform perpetual
* inventory
* 4.1 Version I for estimators that rely mainly on between-firm information
* (e.g. OLS)
* 4.2 Version II for estimators that use only within-firm information (e.g. Fixed
* Effects, First Differences, GMM-Diff, GMM-SYS)
****************************************************************************

****************************************************************************
* 1. import the average economic lives (in years) of industry capital stock (ND)
* from the national accounts - AVAILABLE FROM DESTATIS UPON REQUEST (?)
*variables from the IAB Establishment Panel:
* sectornew is the industry code of the wz93 classification, in the IAB
* Establishment Panel routinely coded from 2000 on
* year is the year of observation, 96 = 1996, 97 = 1997, ..., 107 = 2007


/* Merge idnum (EP estab. identifier) for relevant estab's */
use $data_files_path/orig_bp_betriebe_idnum_alle, clear
merge m:1 betnr using $data_files_path/bp_betriebe_vergew_mindestgröße
keep if _merge == 3
drop _merge
merge 1:m idnum using $data_files_path/betriebspanel
keep if _merge == 3
drop _merge

/* Merge historically consistent  industry codes */
merge m:1 betnr using "$data_files_path/w93_bhp_end_jahr"	
keep if _merge == 3
drop _merge

gen wz03_2 =int(w93_3_gen/10)		//WZ93 and WZ03 are identical at the 3-digit level
ren jahr year

gen sectornew=.

// cf. http://www.norface-migration.org/publ_uploads/NDP_29_12.pdf
replace sectornew = 2 if wz03_2==23
replace sectornew = 2 if wz03_2==40
replace sectornew = 2 if wz03_2==41
replace sectornew = 7 if wz03_2==24
replace sectornew = 8 if wz03_2==25
replace sectornew = 12 if wz03_2==27
replace sectornew = 12 if wz03_2==28
replace sectornew = 13 if wz03_2==29
replace sectornew = 14 if wz03_2==34
replace sectornew = 15 if wz03_2==35
replace sectornew = 16 if wz03_2==30
replace sectornew = 16 if wz03_2==31
replace sectornew = 16 if wz03_2==32
replace sectornew = 17 if wz03_2==33
replace sectornew = 6 if wz03_2==20
replace sectornew = 5 if wz03_2==21
replace sectornew = 4 if wz03_2==17
replace sectornew = 4 if wz03_2==18
replace sectornew = 3 if wz03_2==15
replace sectornew = 3 if wz03_2==16
replace sectornew = 5 if wz03_2==22			

//own re-classification
replace sectornew = 4 if wz03_2==19
replace sectornew = 9 if wz03_2==26
replace sectornew = 6 if wz03_2==36
replace sectornew = 2 if wz03_2==37

drop wz03_2

// Original code of Müller (2010) (http://doku.iab.de/fdz/reporte/2010/MR_02-10-EN.pdf)
// sectornew ist 1, 2, ..., 33

gen ND = .
replace ND = 24.4 if sectornew==2 & year == 2000
replace ND = 17.9 if sectornew==3 & year == 2000
replace ND = 22.4 if sectornew==4 & year == 2000
replace ND = 15.9 if sectornew==5 & year == 2000
replace ND = 20.4 if sectornew==6 & year == 2000
replace ND = 15.8 if sectornew==7 & year == 2000
replace ND = 15.7 if sectornew==8 & year == 2000
replace ND = 16.9 if sectornew==9 & year == 2000
replace ND = 17.4 if sectornew==12 & year == 2000
replace ND = 17.5 if sectornew==13 & year == 2000
replace ND = 15.6 if sectornew==14 & year == 2000
replace ND = 21.0 if sectornew==15 & year == 2000
replace ND = 16.1 if sectornew==16 & year == 2000
replace ND = 18.0 if sectornew==17 & year == 2000

replace ND = 24.6 if sectornew==2 & year == 2001
replace ND = 17.8 if sectornew==3 & year == 2001
replace ND = 22.5 if sectornew==4 & year == 2001
replace ND = 15.9 if sectornew==5 & year == 2001
replace ND = 20.3 if sectornew==6 & year == 2001
replace ND = 15.7 if sectornew==7 & year == 2001
replace ND = 15.7 if sectornew==8 & year == 2001
replace ND = 16.9 if sectornew==9 & year == 2001
replace ND = 17.2 if sectornew==12 & year == 2001
replace ND = 17.4 if sectornew==13 & year == 2001
replace ND = 15.5 if sectornew==14 & year == 2001
replace ND = 20.7 if sectornew==15 & year == 2001
replace ND = 16.0 if sectornew==16 & year == 2001
replace ND = 17.8 if sectornew==17 & year == 2001

replace ND = 24.8 if sectornew==2 & year == 2002
replace ND = 17.7 if sectornew==3 & year == 2002
replace ND = 22.5 if sectornew==4 & year == 2002
replace ND = 15.8 if sectornew==5 & year == 2002
replace ND = 20.1 if sectornew==6 & year == 2002
replace ND = 15.6 if sectornew==7 & year == 2002
replace ND = 15.7 if sectornew==8 & year == 2002
replace ND = 16.8 if sectornew==9 & year == 2002
replace ND = 17.1 if sectornew==12 & year == 2002
replace ND = 17.3 if sectornew==13 & year == 2002
replace ND = 15.3 if sectornew==14 & year == 2002
replace ND = 20.2 if sectornew==15 & year == 2002
replace ND = 15.9 if sectornew==16 & year == 2002
replace ND = 17.7 if sectornew==17 & year == 2002

replace ND = 25.1 if sectornew==2 & year == 2003
replace ND = 17.7 if sectornew==3 & year == 2003
replace ND = 22.7 if sectornew==4 & year == 2003
replace ND = 15.8 if sectornew==5 & year == 2003
replace ND = 20.2 if sectornew==6 & year == 2003
replace ND = 15.6 if sectornew==7 & year == 2003
replace ND = 15.8 if sectornew==8 & year == 2003
replace ND = 16.9 if sectornew==9 & year == 2003
replace ND = 17.0 if sectornew==12 & year == 2003
replace ND = 17.4 if sectornew==13 & year == 2003
replace ND = 15.3 if sectornew==14 & year == 2003
replace ND = 20.1 if sectornew==15 & year == 2003
replace ND = 16.0 if sectornew==16 & year == 2003
replace ND = 17.8 if sectornew==17 & year == 2003

replace ND = 25.7 if sectornew==2 & year == 2004
replace ND = 17.8 if sectornew==3 & year == 2004
replace ND = 23.0 if sectornew==4 & year == 2004
replace ND = 15.9 if sectornew==5 & year == 2004
replace ND = 20.5 if sectornew==6 & year == 2004
replace ND = 15.7 if sectornew==7 & year == 2004
replace ND = 15.9 if sectornew==8 & year == 2004
replace ND = 17.0 if sectornew==9 & year == 2004
replace ND = 17.1 if sectornew==12 & year == 2004
replace ND = 17.6 if sectornew==13 & year == 2004
replace ND = 15.3 if sectornew==14 & year == 2004
replace ND = 20.2 if sectornew==15 & year == 2004
replace ND = 16.1 if sectornew==16 & year == 2004
replace ND = 17.9 if sectornew==17 & year == 2004

replace ND = 26.1 if sectornew==2 & year == 2005
replace ND = 17.8 if sectornew==3 & year == 2005
replace ND = 23.1 if sectornew==4 & year == 2005
replace ND = 15.8 if sectornew==5 & year == 2005
replace ND = 20.4 if sectornew==6 & year == 2005
replace ND = 15.8 if sectornew==7 & year == 2005
replace ND = 15.9 if sectornew==8 & year == 2005
replace ND = 17.1 if sectornew==9 & year == 2005
replace ND = 17.0 if sectornew==12 & year == 2005
replace ND = 17.6 if sectornew==13 & year == 2005
replace ND = 15.2 if sectornew==14 & year == 2005
replace ND = 20.0 if sectornew==15 & year == 2005
replace ND = 16.1 if sectornew==16 & year == 2005
replace ND = 17.9 if sectornew==17 & year == 2005

replace ND = 26.5 if sectornew==2 & year == 2006
replace ND = 17.9 if sectornew==3 & year == 2006
replace ND = 23.4 if sectornew==4 & year == 2006
replace ND = 16.2 if sectornew==5 & year == 2006
replace ND = 20.5 if sectornew==6 & year == 2006
replace ND = 15.8 if sectornew==7 & year == 2006
replace ND = 16.0 if sectornew==8 & year == 2006
replace ND = 17.3 if sectornew==9 & year == 2006
replace ND = 17.1 if sectornew==12 & year == 2006
replace ND = 17.6 if sectornew==13 & year == 2006
replace ND = 15.1 if sectornew==14 & year == 2006
replace ND = 20.0 if sectornew==15 & year == 2006
replace ND = 16.2 if sectornew==16 & year == 2006
replace ND = 18.1 if sectornew==17 & year == 2006

replace ND = 27.1 if sectornew==2 & year == 2007
replace ND = 18.1 if sectornew==3 & year == 2007
replace ND = 24.0 if sectornew==4 & year == 2007
replace ND = 16.3 if sectornew==5 & year == 2007
replace ND = 20.8 if sectornew==6 & year == 2007
replace ND = 15.9 if sectornew==7 & year == 2007
replace ND = 16.1 if sectornew==8 & year == 2007
replace ND = 17.6 if sectornew==9 & year == 2007
replace ND = 17.1 if sectornew==12 & year == 2007
replace ND = 17.8 if sectornew==13 & year == 2007
replace ND = 15.2 if sectornew==14 & year == 2007
replace ND = 20.4 if sectornew==15 & year == 2007
replace ND = 16.4 if sectornew==16 & year == 2007
replace ND = 18.3 if sectornew==17 & year == 2007

	//Update received direclty from Steffen Müller via e-mail

	replace ND = 27.8 if sectornew==2 & year == 2008
	replace ND = 18.4 if sectornew==3 & year == 2008
	replace ND = 24.5 if sectornew==4 & year == 2008
	replace ND = 16.5 if sectornew==5 & year == 2008
	replace ND = 20.7 if sectornew==6 & year == 2008
	replace ND = 16.1 if sectornew==7 & year == 2008
	replace ND = 16.3 if sectornew==8 & year == 2008
	replace ND = 18.0 if sectornew==9 & year == 2008
	replace ND = 17.3 if sectornew==12 & year == 2008
	replace ND = 18.0 if sectornew==13 & year == 2008
	replace ND = 15.3 if sectornew==14 & year == 2008
	replace ND = 20.9 if sectornew==15 & year == 2008
	replace ND = 17.4 if sectornew==16 & year == 2008
	replace ND = 18.5 if sectornew==17 & year == 2008

	replace ND = 27.7 if sectornew==2 & year == 2009
	replace ND = 18.3 if sectornew==3 & year == 2009
	replace ND = 24.4 if sectornew==4 & year == 2009
	replace ND = 16.5 if sectornew==5 & year == 2009
	replace ND = 20.7 if sectornew==6 & year == 2009
	replace ND = 16.0 if sectornew==7 & year == 2009
	replace ND = 16.3 if sectornew==8 & year == 2009
	replace ND = 18.1 if sectornew==9 & year == 2009
	replace ND = 17.2 if sectornew==12 & year == 2009
	replace ND = 17.9 if sectornew==13 & year == 2009
	replace ND = 15.1 if sectornew==14 & year == 2009
	replace ND = 21.0 if sectornew==15 & year == 2009
	replace ND = 16.6 if sectornew==16 & year == 2009
	replace ND = 18.4 if sectornew==17 & year == 2009

	replace ND = 27.7 if sectornew==2 & year == 2010
	replace ND = 18.3 if sectornew==3 & year == 2010
	replace ND = 24.4 if sectornew==4 & year == 2010
	replace ND = 16.5 if sectornew==5 & year == 2010
	replace ND = 20.7 if sectornew==6 & year == 2010
	replace ND = 16.0 if sectornew==7 & year == 2010
	replace ND = 16.3 if sectornew==8 & year == 2010
	replace ND = 18.1 if sectornew==9 & year == 2010
	replace ND = 17.2 if sectornew==12 & year == 2010
	replace ND = 17.9 if sectornew==13 & year == 2010
	replace ND = 15.1 if sectornew==14 & year == 2010
	replace ND = 21.0 if sectornew==15 & year == 2010
	replace ND = 16.6 if sectornew==16 & year == 2010
	replace ND = 18.4 if sectornew==17 & year == 2010

	replace ND = 27.7 if sectornew==2 & year == 2011
	replace ND = 18.3 if sectornew==3 & year == 2011
	replace ND = 24.4 if sectornew==4 & year == 2011
	replace ND = 16.5 if sectornew==5 & year == 2011
	replace ND = 20.7 if sectornew==6 & year == 2011
	replace ND = 16.0 if sectornew==7 & year == 2011
	replace ND = 16.3 if sectornew==8 & year == 2011
	replace ND = 18.1 if sectornew==9 & year == 2011
	replace ND = 17.2 if sectornew==12 & year == 2011
	replace ND = 17.9 if sectornew==13 & year == 2011
	replace ND = 15.1 if sectornew==14 & year == 2011
	replace ND = 21.0 if sectornew==15 & year == 2011
	replace ND = 16.6 if sectornew==16 & year == 2011
	replace ND = 18.4 if sectornew==17 & year == 2011

	replace ND = 27.7 if sectornew==2 & year == 2012
	replace ND = 18.3 if sectornew==3 & year == 2012
	replace ND = 24.4 if sectornew==4 & year == 2012
	replace ND = 16.5 if sectornew==5 & year == 2012
	replace ND = 20.7 if sectornew==6 & year == 2012
	replace ND = 16.0 if sectornew==7 & year == 2012
	replace ND = 16.3 if sectornew==8 & year == 2012
	replace ND = 18.1 if sectornew==9 & year == 2012
	replace ND = 17.2 if sectornew==12 & year == 2012
	replace ND = 17.9 if sectornew==13 & year == 2012
	replace ND = 15.1 if sectornew==14 & year == 2012
	replace ND = 21.0 if sectornew==15 & year == 2012
	replace ND = 16.6 if sectornew==16 & year == 2012
	replace ND = 18.4 if sectornew==17 & year == 2012







****************************************************************************
* 2. generate economic lives for net investments
*variables from the IAB Establishment Panel:
* inv = total investment
* IPlant = Dummy = 1 if investments in real estate or buildings
* IIT = Dummy = 1 if investments in IT or communication equipments
* IProd = Dummy = 1 if investments in production machinery or other equipments
* ITransp = Dummy = 1 if investments in transport equipment
*for every year the same average life of a certain new capital good is inserted
*(numbers taken from internal computations of the federal statistical bureau)
*Dummy Value is replaced with average economic life if the Dummy was == 1 before

replace IPlant = 66 if IPlant==1
replace IPlant = 0 if IPlant==.
replace IIT = 7 if IIT==1
replace IIT = 0 if IIT==.
replace IProd = 15 if IProd==1
replace IProd = 0 if IProd==.
replace ITransp = 12 if ITransp==1
replace ITransp = 0 if ITransp==.


*generate variable ND__InvNet containing the avarage life of net investments
* Note: Each Combination of IPlant+IIT+IProd+ITransp gives an unique identification
* of which type of net investment actually took place
**Example:
* IPlant+IIT+IProd+ITransp==19 means that there were investments in IIT and ITransp
* and no investments in IPlant and IProd the mean of econ. lives of IIT and ITransp * == (7+12)/2 = 9.5
gen ND__InvNet = ND
replace ND__InvNet = 7 if IPlant+IIT+IProd+ITransp==7
replace ND__InvNet = 12 if IPlant+IIT+IProd+ITransp==12
replace ND__InvNet = 15 if IPlant+IIT+IProd+ITransp==15
replace ND__InvNet = 66 if IPlant+IIT+IProd+ITransp==66
replace ND__InvNet = 9.5 if IPlant+IIT+IProd+ITransp==19
replace ND__InvNet = 11 if IPlant+IIT+IProd+ITransp==22
replace ND__InvNet = 13.5 if IPlant+IIT+IProd+ITransp==27
replace ND__InvNet = 11.3 if IPlant+IIT+IProd+ITransp==34
replace ND__InvNet = 36.5 if IPlant+IIT+IProd+ITransp==73
replace ND__InvNet = 39 if IPlant+IIT+IProd+ITransp==78
replace ND__InvNet = 40.5 if IPlant+IIT+IProd+ITransp==81
replace ND__InvNet = 28.3 if IPlant+IIT+IProd+ITransp==85
replace ND__InvNet = 29.3 if IPlant+IIT+IProd+ITransp==88
replace ND__InvNet = 31 if IPlant+IIT+IProd+ITransp==93
replace ND__InvNet = 25 if IPlant+IIT+IProd+ITransp==100

*recode the Dummies as ND__Invnet now is created
replace IIT = 1 if IIT == 7
replace IPlant = 1 if IPlant==66
replace IProd = 1 if IProd==15
replace ITransp = 1 if ITransp==12

****************************************************************************
* 3. multiply the replacement investment for each firm-year observation with the ND
*variables from the IAB Establishment Panel:
*inv_dK = percentage of net investments in total investment (0 - 100)
*First assumption on missing values:
****there are numerous missing values in the variable inv_dK
****the Researcher may decide to make assumptions about the missing data and impute
****plausible values
****one possibility is the following:
****impute missing information on the share of net investments with the firm-
****specific average if investments are known:

ren invest_erw inv_dK

sort idnum year
by idnum: egen meaninv_dK = mean(inv_dK)
replace inv_dK = meaninv_dK if inv_dK == . & invest !=.		
*End assumption on missing values in inv_dK
* generate level of net investments


gen InvNe = invest*(inv_dK/100)
* generate level of net replacements
gen InvRe = invest*(100-inv_dK)/100



****************************************************************************
* 4.1 Version I for estimators that rely mainly on between-firm information
* (e.g. OLS) 

*** omitted



****************************************************************************
* 4.2 Version II for estimators that use only within-firm information
* (e.g. Fixed Effects, First Differences, GMM-Diff, GMM-SYS)
*takes the arithmetic mean of the replacements of the first three years
*the firm is in the data as a starting value

*4.2.1

**multiply replacements with economic lives for each year
gen K = InvRe*ND

*4.2.2


/*Adjust for restructuring events (cf. Ehrl, Philipp. "Agglomeration economies with consistent productivity estimates." Regional Science and Urban Economics 43.5 (2013): 751-763.)*/

foreach var of varlist sold_off closed_down spun_off insource {
replace `var'=. if `var' <0
}

foreach var of varlist sold_off closed_down spun_off insource {
replace `var'=0 if `var'==2
}

gen restruct = 0
foreach var of varlist sold_off closed_down spun_off insource {
replace restruct=1 if `var'==1
}

//============================================
//No restructuring event:
																					
* generate SMA3 (starting value with 3 years of support) for the second
* observation of that firm
gen SMA3 = .
sort idnum year
replace SMA3 = (1/3)*(K[_n-1] + K + K[_n+1]) if idnum[_n-2] != idnum & idnum[_n-1] == idnum[_n+1] & restruct==0 & restruct[_n-1]==0 & restruct[_n+1]==0

* insert SMA3 into the first year of panel participation as capital stock
* value and in order to gain one observation for perpetual inventory
gen K3 = .
sort idnum year
replace K3 = SMA3[_n+1] if idnum[_n-1] != idnum & idnum == idnum[_n+1] & restruct==0


*4.2.3

*i. start perpetual inventory, analogue to K3, here compute depreciation
sort idnum year
gen DEP3 = .
replace DEP3 = K3[_n-1]/ND[_n-1] if idnum[_n-1] == idnum  & restruct==0 

*ii. compute expected change in capital stock, given total investments and
* depreciation on last years capital and on half of this years net investments
gen dK3 = .
replace dK3 = (InvRe-DEP3)+InvNe-(0.5*(InvNe/ND__InvNet)) if restruct==0 
replace K3 = K3[_n-1] + dK3 if idnum[_n-1] == idnum & restruct==0 

*iii. the routine has to be repeated iteratively because for each year first
* depreciation and the capital stock has to be computed
sort idnum year
replace DEP3 = K3[_n-1]/ND[_n-1] if idnum[_n-1] == idnum & DEP3==. & restruct==0 
//works only if K3[_n-1] (== second year) and ND[_n-1] exist
replace dK3 = (InvRe-DEP3)+InvNe-(0.5*(InvNe/ND__InvNet)) if dK3==. & restruct==0
//works only if investments are known, and DEP3 and ND__InvNet exist
replace K3 = K3[_n-1] + dK3 if idnum[_n-1] == idnum & restruct==0 
//writes K3 into the next line if dK3 exists

*Second assumption on Missing Values analogue to KT
replace K3 = K3[_n-1] if idnum[_n-1] == idnum[_n+1] & K3==. & invest==. & invest[_n+1]!=. & restruct==0  
//works not: if K3[_n-1] is missing, or if this is the last year of the
// firm, or if inv is missing in the next year

*** then, perpetual inventory is repeated for each year of panel participation
*** while treating missing values as mentioned above


// ITERATIONS

// For 3rd-10th wave (2003-2010), i.e. 8 iterations

forv k = 1/8 {
di "`k'-te Iteration"
sort idnum year
replace DEP3 = K3[_n-1]/ND[_n-1] if idnum[_n-1] == idnum & DEP3==. & restruct==0 
replace dK3 = (InvRe-DEP3)+InvNe-(0.5*(InvNe/ND__InvNet)) if dK3==. & restruct==0
replace K3 = K3[_n-1] + dK3 if idnum[_n-1] == idnum & restruct==0 
replace K3 = K3[_n-1] if idnum[_n-1] == idnum[_n+1] & K3==. & invest==. & invest[_n+1]!=. & restruct==0  
}

//============================================
//Establishmetns with restructuring events:
																					
sort idnum year
replace SMA3 = (1/3)*(K[_n-1] + K + K[_n+1]) if idnum==idnum[_n-1] & idnum == idnum[_n+1] & restruct[_n-1]==1 & restruct==0 & restruct[_n+1]==0

replace K3 = SMA3[_n+1] if idnum == idnum[_n+1] & restruct[_n+1]==0 & restruct==1 & restruct[_n+1]==0
replace DEP3 = K3[_n-1]/ND[_n-1] if idnum == idnum[_n-1] & restruct==0 & restruct[_n-1]==1
replace dK3 = (InvRe-DEP3)+InvNe-(0.5*(InvNe/ND__InvNet)) if idnum == idnum[_n-1] & restruct==0 & restruct[_n-1]==1 
replace K3 = K3[_n-1] + dK3 if idnum == idnum[_n-1] & restruct==0 & restruct[_n-1]==1

forv k = 1/9 {
di "`k'-te Iteration"
sort idnum year
replace DEP3 = K3[_n-1]/ND[_n-1] if idnum[_n-1] == idnum & DEP3==. & restruct==0 
replace dK3 = (InvRe-DEP3)+InvNe-(0.5*(InvNe/ND__InvNet)) if dK3==. & restruct==0
replace K3 = K3[_n-1] + dK3 if idnum[_n-1] == idnum & restruct==0 
replace K3 = K3[_n-1] if idnum[_n-1] == idnum[_n+1] & K3==. & invest==. & invest[_n+1]!=. & restruct==0  
}								

																	
sort idnum year
replace SMA3 = (1/3)*(K[_n-1] + K + K[_n+1])				if idnum[_n-2]==idnum[_n+1] 	& restruct==0 & restruct[_n+1]==0 	     & K[_n-2]==. & K3[_n-1]==.   & K3==.   & K3[_n+1]==. 
replace K3 = SMA3[_n+1] 									if   idnum==idnum[_n+1]			& restruct[_n+1]==0 & restruct[_n+2]==0                 & K3==.   & K3[_n+1]==.  & K3[_n+2]==. 
replace DEP3 = K3[_n-1]/ND[_n-1] 							if idnum[_n-2]==idnum[_n+1] 	& restruct==0 & restruct[_n+1]==0 		 & K[_n-2]==. & DEP3[_n-1]==. & DEP3==. & DEP3[_n+1]==.
replace dK3 = (InvRe-DEP3)+InvNe-(0.5*(InvNe/ND__InvNet)) 	if idnum[_n-2]==idnum[_n+1] 	& restruct==0 & restruct[_n+1]==0 		 & K[_n-2]==. & dK3[_n-1]==.  & dK3==.  & dK3[_n+1]==. 
replace K3 = K3[_n-1] + dK3 								if  idnum[_n-1]==idnum[_n+1]     & restruct==0 & restruct[_n+1]==0 & K3==.   & K3[_n+1]==.

forv k = 1/9 {
di "`k'-te Iteration"
sort idnum year
replace DEP3 = K3[_n-1]/ND[_n-1] if idnum[_n-1] == idnum & DEP3==. & restruct==0 
replace dK3 = (InvRe-DEP3)+InvNe-(0.5*(InvNe/ND__InvNet)) if dK3==. & restruct==0
replace K3 = K3[_n-1] + dK3 if idnum[_n-1] == idnum & restruct==0 & K3==.
replace K3 = K3[_n-1] if idnum[_n-1] == idnum[_n+1] & K3==. & invest==. & invest[_n+1]!=. & restruct==0 & K3==.  
}								
 

label var K3 "capital_stock"
label var dK3 "capital_change"

drop K

drop ND__InvNet meaninv_dK SMA3

ren year jahr

keep jahr betnr idnum K3 InvNe
keep if jahr>2001 & jahr<2011


foreach var of varlist K3 {
replace `var' = `var'*1.000 if jahr==2010
replace `var' = `var'*1.011 if jahr==2009
replace  `var' = `var'*1.014	if jahr==2008
replace  `var' = `var'*1.041	if jahr==2007
replace  `var' = `var'*1.065	if jahr==2006
replace  `var' = `var'*1.082	if jahr==2005
replace `var' = `var'*1.098	if jahr==2004
replace  `var' = `var'*1.117	if jahr==2003
replace  `var' = `var'*1.128 if jahr==2002
}

save $data_files_path/kontrollvariablen_betriebspanel_Kapitalstock_2002_2010, replace

log close
