cap log close
log using $log_files_path/sample_ep, replace

use $data_files_path/kontrollvariablen_betriebsebene, clear

/* Step 1: Establishment age - at least 3 years (necessary to construct lagged variables)*/

gen byte zu_jung =  betr_alt<3
drop if zu_jung == 1
drop zu_jung

/* Step 2: Establishments must still exist on June, 30 of the respective year (reference date of the BHP) */
drop if non_bhp_existent == 1
drop non_bhp_existent

/* Step 3: value-added, capital and export-share must be non-missing and non-zero (since we have to work with logarithms)	*/
gen byte mis_value_added = value_added == .
gen byte neg_value_added = value_added <= 0
drop if mis_value_added == 1 | neg_value_added == 1
drop mis* neg*

gen byte mis_K3 = K3 == .
gen byte zero_K3 = K3 <= 0
drop if mis_K3 == 1 | zero_K3 == 1
drop mis* zero*

drop if export_share == .

/* Step 4: Plausibility check and cleaning of observations with substantial differences in total employment according to EP vs. BHP */
gen az_ges_vgl = az_ges - az_gf
gen test=(az_ges_vgl-svbv)/svbv
replace test=1 if test==.
replace test = -test if test<0


gen dif = az_ges_vgl - svbv
replace dif = -dif if dif<0


gen byte sizecat=svbv<5
replace sizecat=2 if svbv>4 & svbv<20
replace sizecat=3 if svbv>19 & svbv<100
replace sizecat=4 if svbv>99 & svbv<500
replace sizecat=5 if svbv>499 & svbv~=.


gen test1 = sizecat==1 & test>.4  & dif>=3
gen test2 = sizecat==2 & test>.3 & dif>=4

gen test3 = sizecat==3 & test>.2  & dif>=6
gen test4 = sizecat==4 & test>.1  & dif>=15
gen test5 = sizecat==5 & test>.1 

tab test1 if sizecat == 1
tab test2 if sizecat == 2
tab test3 if sizecat == 3
tab test4 if sizecat == 4
tab test5 if sizecat == 5

local a = _N
forval i = 1/5{
drop if test`i' == 1
}
di "Anteil gelöscht:"
di (`a'-_N)/`a'
drop test* sizecat dif




keep betnr idnum jahr

save $data_files_path/sample_ep_ende, replace


log close
