
cap log close
log using $log_files_path/inflows_identification, replace

cd "$data_files_path"

/* Outline */
/* 1. step: Identify potential inflows --> employed in a relevant EP establishment on Jan 1 of year i 
               full-time and covered by social security*/
/* 2. Step: Handling of parallel spells */
/* 3. Step: Comprise spells within one establishment (max gap between spells: 6 days) and delete
            employment relationships shorter than 7 days */
/* 4. Step: Identify inflows and their date of arrival*/  
/* 5. Step: Identifcation of inflows from other establishments*/  
/* 6. Step: Adding former unempoyment and former employment information to relevant employment spell and keeping only these relevant spells*/  
/* 7. Step: Only qualified inflows with sensible wage information, age between 15-64 years, max 92 days of umemployment,
            if no unemployment max. gap with no information 183 days; no missing information on occuption, region and industry */  


forval i = 2002/2010{


/* **************************************************************************************************** */
/* First step: Identify potential inflows --> employed in a relevant EP establishment on Jan 1 of year i 
               full-time and covered by social security*/
use ieb_`i', clear	// IEB dataset
drop if betnr == . & quelle == 1  // missing establishmend ID
gen byte tz = inrange(berufstellg_num,7,9) if quelle == 1  // indicator part-time
drop if tz==1											   // drop part-time
drop tz		
drop if quelle==1 & erw_stat_num~=101						// drop if not covered by social security

/*Identify spells of persons employed on Jan 1 of year i in a relevant EP establishment (fullt-time, covered by social security)*/
gen jahr = `i'
merge m:1 betnr jahr using sample_ep_ende
gen byte ep_estab_relevant= _merge == 3 // indicator relevant EP establishment


gen byte besch_bp_0101`i' = (quelle == 1 & begepi<=d(01jan`i')  & endepi>=d(01jan`i') & ep_estab_relevant == 1)
label var besch_bp_0101`i' "Indicator relevant employment spell for inflows: Jan 1 of year i in a EP establishment"
drop ep_estab_relevant

/*Identify all spells of these persons*/
bys id: egen besch_bp_id = max(besch_bp_0101`i')
/* Keep only these spells */
keep if besch_bp_id == 1

drop _merge besch_bp_id

/* End of first step */
/* ********************************************************************************************************** */


/* ******************************************************************************************************** */
/* 2. Step: Handling of parallel spells */

/* Parallel unemployment spelle */ 
duplicates drop begepi endepi id if quelle~=1, force
		
/*  Parallel spells in the same establishment */
	bys id betnr begepi: egen double tag_entg_gesamt = total(tag_entg) if quelle == 1 // daily wage adjustment before dropping
    duplicates drop id betnr begepi tag_entg_gesamt if quelle == 1, force
	replace tag_entg = tag_entg_gesamt if quelle == 1
	drop tag_entg_gesamt
	

/* Parallel spells in different establishments */ 
	bys id begepi: egen double test_max =  max(tag_entg) if quelle == 1
	gen byte indikator_level1 = (test_max == tag_entg) if quelle == 1
	drop if indikator_level1 == 0 & quelle == 1 //  keep only that with higher wage
    drop test_max indikator_level1
	bys id: egen test = total(besch_bp_0101`i') // drop anyone who is not mainly employed in a relevant establishment on Jan 1, year i 
	drop if test == 0
	drop test
	
/* Delete the remaining persons who still have parallel full-time employment spells covered by social security */
	gen eins = 1
	bys id begepi: egen zaehler = total(eins) if quelle == 1
	bys id: egen test_zaehler = max(zaehler)
	drop if test_zaehler ~=1
	drop  eins test_zaehler zaehler


/* Delete spells of unemployment during employment */
	replace quelle = 2 if quelle ~= 1
	sort id begepi quelle 
	drop if id == id[_n-1] & begepi == begepi[_n-1] & quelle[_n-1]== 1 & quelle == 2
	
/* Test */
	sort id begepi
	count if id == id[_n-1] & begepi == begepi[_n-1]
    if r(N) ~= 0 {
    dis as red "Warning: Duplicates remain!"
    }	
	
/* End Step 2 */ 
/****************************************************************************************** */
	

/* ******************************************************************************************************** */
/* 3. Step: Comprise spells within one establishment (max gap between spells: 6 days) and delete
            employment relationships shorter than 7 days */
	

/* a.) Employment establishment A, employment establishment B (less than six days), employment establishment A --> delete employment spell establishment B */
	sort id begepi 
	gen byte test = ( id == id[_n-1] & id==id[_n+1] & quelle == 1 & quelle[_n-1]== 1 ///
					& quelle[_n+1] == 1 & begepi ==endepi[_n-1]+1 & endepi==begepi[_n+1]-1 ///
					& betnr[_n-1]==betnr[_n+1] & betnr ~=betnr[_n+1] & endepi-begepi<=5)
	drop if test == 1  
	drop test
	
/* b.) comprise spells - new begin and end date */
sort id quelle idnum begepi endepi
gen beg_besch_betrieb_temp = begepi if quelle == 1
replace beg_besch_betrieb_temp = beg_besch_betrieb_temp[_n-1] if quelle == quelle[_n-1] & ///
     quelle == 1 & ///
     beg_besch_betrieb_temp[_n-1] != . & betnr == betnr[_n-1] & ///
     begepi - endepi[_n-1] <= 7 & ///
       id  == id[_n-1]
bysort id beg_besch_betrieb_temp: egen end_besch_betrieb_temp = max(endepi) if beg_besch_betrieb_temp != .
bys id beg_besch_betrieb_temp: egen beg_besch_betrieb = min(beg_besch_betrieb_temp)
bys id end_besch_betrieb_temp: egen end_besch_betrieb = min(end_besch_betrieb_temp)
format beg_besch_betrieb end_besch_betrieb %tdD_m_Y
gen beschspell_dauer_tage = end_besch_betrieb - beg_besch_betrieb + 1
drop end_besch_betrieb_temp beg_besch_betrieb_temp


/* c.) Compute average daily wage during employment relationship (which may comprise several spells, see step b)*/
gen spell_dauer = endepi-begepi +1 if beg_besch_betrieb ~=.
gen double tag_entg_temp = tag_entg
gen sum_entg_spell = tag_entg_temp*spell_dauer
bys id beg_besch_betrieb: egen sum_entg_besch = total(sum_entg_spell) if beg_besch_betrieb~=.
gen b_entg = sum_entg_besch/beschspell_dauer_tage
drop spell_dauer tag_entg_temp sum_entg_spell sum_entg_besch

/* d.) Delete employment relationships <7 days*/
drop if beschspell_dauer_tage<=7
 bys id: egen test = total(besch_bp_0101`i')  // drop anyone who is not mainly employment in a in a relevant establishment on Jan 1, year i caused by delete <7 days
	drop if test == 0
	drop test

	
/* e.) Indicate all spells belonging to the relevant employment relationship (i.e. in a relevant EP establishment and containing Jan 1, year i)*/
bys id beg_besch_bet: egen indikator_besch_bp_`i'0101 = max(besch_bp_0101`i')
  label var indikator_besch_bp_`i'0101 "alle Spells die zum entscheidenden Beschverhältnis im BP-Betrieb gehören"	
	
/* f.) Delete parallel spells of unemployment benefit receipt (caused bei step b) */
sort id begepi
drop if id == id[_n-1] & quelle == 2 & quelle[_n-1]==1 & begepi >beg_besch[_n-1] & begepi<end_besch[_n-1]
sort id begepi
drop if id == id[_n-1] & quelle == 2 & quelle[_n-1]==1 & begepi >beg_besch[_n-1] & begepi<end_besch[_n-1]


	
/* g.) Comprise unemployment spells (max. gap between spells: 6 days)*/ 
sort id quelle begepi endepi
gen beg_leistung_temp = begepi if quelle == 2
replace beg_leistung_temp = beg_leistung_temp[_n-1] if quelle == quelle[_n-1] & ///
     quelle == 2 & ///
     beg_leistung_temp[_n-1] != . & ///
     begepi - endepi[_n-1] <= 7  & ///
       id  == id[_n-1]
bysort id beg_leistung_temp: egen end_leistung_temp = max(endepi) if beg_leistung_temp != .
bys id beg_leistung_temp: egen beg_leistung = min(beg_leistung_temp)
bys id end_leistung_temp: egen end_leistung = min(end_leistung_temp)
format beg_leistung end_leistung %tdD_m_Y
drop beg_leistung_temp end_leistung_temp
gen dauer_leistung_tage = end_leistung - beg_leistung+1 


/* End Step 3*/ 
/****************************************************************************************** */
	

/* ******************************************************************************************************** */
/* 4. Step: Identify inflows and their date of arrival*/  

/* a.) Compute duration (in months) since the beginning of the employment relationship*/

local vor_bp_jahr = `i'-1
local vor_vor_bp_jahr=`i'-2
local vor_vor_vor_bp_jahr=`i'-3

gen byte in_vor1monat= (beg_besch_betrieb>d(30nov`vor_bp_jahr')  & besch_bp_0101`i' ==1)	
gen byte in_vor2monat= (beg_besch_betrieb>d(31oct`vor_bp_jahr')  & besch_bp_0101`i' ==1)
gen byte in_vor3monat= (beg_besch_betrieb>d(30sep`vor_bp_jahr')  & besch_bp_0101`i' ==1)
gen byte in_vor4monat= (beg_besch_betrieb>d(31aug`vor_bp_jahr')  & besch_bp_0101`i' ==1)
gen byte in_vor5monat= (beg_besch_betrieb>d(31jul`vor_bp_jahr')  & besch_bp_0101`i' ==1)
gen byte in_vor6monat= (beg_besch_betrieb>d(30jun`vor_bp_jahr')  & besch_bp_0101`i' ==1)
gen byte in_vor7monat= (beg_besch_betrieb>d(31may`vor_bp_jahr')  & besch_bp_0101`i' ==1)
gen byte in_vor8monat= (beg_besch_betrieb>d(30apr`vor_bp_jahr')  & besch_bp_0101`i' ==1)
gen byte in_vor9monat= (beg_besch_betrieb>d(31mar`vor_bp_jahr')  & besch_bp_0101`i' ==1)
gen byte in_vor10monat= (beg_besch_betrieb>d(28feb`vor_bp_jahr')  & besch_bp_0101`i' ==1)
gen byte in_vor11monat= (beg_besch_betrieb>d(31jan`vor_bp_jahr')  & besch_bp_0101`i' ==1)
gen byte in_vor12monat= (beg_besch_betrieb>d(31dec`vor_vor_bp_jahr')  & besch_bp_0101`i' ==1)
gen byte in_vor13monat= (beg_besch_betrieb>d(30nov`vor_vor_bp_jahr')  &besch_bp_0101`i' ==1)	
gen byte in_vor14monat= (beg_besch_betrieb>d(31oct`vor_vor_bp_jahr')  & besch_bp_0101`i' ==1)
gen byte in_vor15monat= (beg_besch_betrieb>d(30sep`vor_vor_bp_jahr')  & besch_bp_0101`i' ==1)
gen byte in_vor16monat= (beg_besch_betrieb>d(31aug`vor_vor_bp_jahr')  & besch_bp_0101`i' ==1)
gen byte in_vor17monat= (beg_besch_betrieb>d(31jul`vor_vor_bp_jahr')  & besch_bp_0101`i' ==1)
gen byte in_vor18monat= (beg_besch_betrieb>d(30jun`vor_vor_bp_jahr')  & besch_bp_0101`i'==1)
gen byte in_vor19monat= (beg_besch_betrieb>d(31may`vor_vor_bp_jahr')  & besch_bp_0101`i'==1)
gen byte in_vor20monat= (beg_besch_betrieb>d(30apr`vor_vor_bp_jahr')  & besch_bp_0101`i' ==1)
gen byte in_vor21monat= (beg_besch_betrieb>d(31mar`vor_vor_bp_jahr')  & besch_bp_0101`i' ==1)
gen byte in_vor22monat= (beg_besch_betrieb>d(28feb`vor_vor_bp_jahr')  & besch_bp_0101`i' ==1)
gen byte in_vor23monat= (beg_besch_betrieb>d(31jan`vor_vor_bp_jahr')  & besch_bp_0101`i' ==1)
gen byte in_vor24monat= (beg_besch_betrieb>d(31dec`vor_vor_vor_bp_jahr')  & besch_bp_0101`i' ==1)		


 egen  test = rsum(in_vor1monat-in_vor24monat) if besch_bp_0101`i' == 1  
 gen temp_in_vorwievielenMonaten = 24 - test + 1
 replace temp_in_vorwievielenMonaten = 99 if test == 0
 bys id beg_besch_betrieb: egen in_vorwievielenMonaten = max(temp_in_vorwievielenMonaten) if besch_bp_0101`i' ~=.
 drop test  temp_*  in_vor1monat-in_vor24monat 

 

 /* b.) Delete persons who are not inflows of the past 24 months*/
  gen byte inflow_temp = (in_vorwievielenMonaten<99)
   bys id: egen inflow = max(inflow_temp)
   drop if inflow~=1
   drop inflow
   drop inflow_temp

 /* c.) Elimination of unnecessary information */
/* Drop employment spells after the relevant employment relationship (i.e. in a relevant EP establishment and containing Jan 1, year i) */
 drop if beg_besch_betrieb > d(01jan`i') & quelle == 1
/* Keep unemployment spells after the relevant date */
 drop if begepi > d(01jan`i')  & quelle ~= 1
 /* Keep only unemployment spells that are directly before the relevant relationship */
	global run = 1
	while $run == 1 {
	sort id begepi
	gen byte test_temp = quelle == 2 & quelle[_n+1] == 1 & indikator_besch_bp[_n+1] == 0 
	bys id beg_leistung: egen test = max(test_temp)
	count if test == 1
	local test = r(N)
	drop if test == 1
	drop test_temp test
	if `test' == 0 {
			global run = 0
			}
		else {
			global run = 1
			}
		}

/* End Step 4*/ 
/****************************************************************************************** */



/* ******************************************************************************************************** */
/* 5. Step: Identifcation of inflows from other establishments*/  

/* Delete inflows from the same establishment */
sort id quelle beg_besch_betrieb end_besch_betrieb
gen long temp_betnr_vor_spell_`i'0101 = betnr[_n-1] if indikator_besch_bp_`i'0101==1 & beg_besch_betrieb~=beg_besch_betrieb[_n-1] & id == id[_n-1]
bys id beg_besch_betrieb: egen long betnr_vor_beschspell_`i'0101 = max(temp_betnr_vor_spell_`i'0101)   
drop temp_betnr_vor_spell_`i'0101 

gen byte gleicher_betrieb = (betnr_vor_beschspell_`i'0101 == betnr) if indikator_besch_bp_`i'0101==1
bys id: egen id_gleicher_betrieb = max(gleicher_betrieb)
drop if id_gleicher_betrieb == 1
drop gleicher_betrieb id_gleicher_betrieb 
 
  
/* Delete inflows without information on sending establishment (two reasons: no employment before or former employment has ended more than three years ago)  */
sort id begepi 
bys id: egen test_temp = max(betnr_vor_beschspell_`i'0101)
gen byte keine_information  = test_temp == .
drop if keine_information == 1
drop test_temp keine_information

/* End of Step 5 */
/* ********************************************************************************************************* */


/* ******************************************************************************************************** */
/* 6. Step: Adding former unempoyment and former employment information to relevant employment spell and keeping only these relevant spells*/  

/* Unemployment spell information */
sort id begepi quelle 
foreach var of varlist dauer_leistung_tage beg_leistung end_leistung{
replace `var' = `var'[_n-1] if indikator_besch_bp_`i'0101 == 1 & `var'[_n-1]~=. & `var' == . & id == id[_n-1] & quelle == 1 & quelle[_n-1] == 2
}

foreach var of varlist dauer_leistung_tage beg_leistung end_leistung{
bys id beg_besch_betrieb: egen `var'_vor_`i'0101 = min(`var') if quelle == 1
}

format beg_leistung_vor_`i'0101 end_leistung_vor_`i'0101 %tdD_m_Y

/* Deleting unemployment spells */
drop if quelle~=1
drop quelle 


/* Information on former employment (beg, end, establ.id, occupation, region, wage etc.) */ 
rename berufstellg_num berufstell
rename beg_besch_betrieb beg_besch
rename end_besch_betrieb end_besch

sort id beg_besch begepi end_besch										
foreach var of varlist beg_besch end_besch  idnum  beruf_num berufstell  arb_kr wohn_kr b_entg w93_3_gen{

gen t_`var'_beschvor_`i'0101 = `var'[_n-1] if indikator_besch_bp_`i'0101==1 & beg_besch~=beg_besch[_n-1] & id == id[_n-1]
bys id beg_besch: egen `var'_beschvor_`i'0101 = max(t_`var'_beschvor_`i'0101)
}

gen long t_betnr_beschvor_`i'0101 = betnr[_n-1] if indikator_besch_bp_`i'0101==1 & beg_besch~=beg_besch[_n-1] & id == id[_n-1]
bys id beg_besch: egen long betnr_beschvor_`i'0101 = max(t_betnr_beschvor_`i'0101)

drop t_*

keep if besch_bp_0101`i' ==1	

drop begepi endepi  besch_bp_0101`i' indikator_besch_bp_`i'0101 


/* End of Step 6 */
/* ********************************************************************************************************* */


/* ******************************************************************************************************** */
/* 7. Step: Only qualified inflows with sensible wage information, between 15-64 years old, max 92 days of umemployment,
            if no unemployment max. gap with no information 183 days; no missing information on occuption, region and industry */  
			
/* Keep only qualified inflows (vocational or academic degree) */
keep if ausbild == 2 | inrange(ausbild,4,6)


/* Delete if wage=0 in either sending or receiving establishment */
drop if b_entg_beschvor_`i'0101 == 0
drop if b_entg == 0

/*Delete the bottom percentile in terms of wage, since this contains implausibly low values*/
su b_entg_beschvor_`i'0101 , de
drop if b_entg_beschvor_`i'0101 < r(p1)
su b_entg , de
drop if b_entg < r(p1)


/* Apply min and max age */
gen gebjahr = year(geb_dat)
gen age = `i'-gebjahr
drop if age < 15
drop if age > 65
cap drop age
drop gebjahr

/* Drop if gap to former employment or former unemployment period is too long employment   */
drop if dauer_leistung_tage_vor_`i'0101 > 92 & dauer_leistung_tage_vor_`i'0101~=.
gen anderer_betrieb_luecke_tage = beg_besch-end_besch_beschvor_`i'0101
drop if anderer_betrieb_luecke_tage > 183			
			

/* Delete if industry, occupation etc. for previuous job is missing */
drop if w93_3_gen_beschvor == -99
drop if arb_kr ==.
drop if arb_kr_beschvor == . 
drop if beruf_num < 0 | beruf_num ==.
drop if beruf_num_beschvor <0 | beruf_num_beschvor == .



   drop if in_vorwievielenMonaten>12
   
 
drop beg_leistung_vor* end_leistung_vor* beg_besch_beschvor* end_besch_beschvor* dauer_leistung_tage_*
drop in_vorwievielenMonaten beschspell_dauer_tage 
drop  w93_3_gen_beschvor 
 drop tag_entg anderer_betrieb_luecke_tage beg_leistung end_leistung dauer_leistung_tage 



 save $data_files_path/neuzugänge_betriebswechsler_clean_t1_`i', replace
 
 }
