
// Betriebsfixe Lohneffekte auf Basis der BeH berechnen
// sowie individuelle Residuen behalten und normalisieren
// (fr mehrere Jahre; jeweils Cross-Sections mit allen Beschftigten aller Betriebe
// oder einer Auswahl von Betrieben)

cap log close
log using $log/Betriebseffekt_Teil1_$date, replace

set rmsg on

// Laden der BeH

use betnr prs_id beh_beg_dat beh_end_dat beh_sex_id beh_geb_dat beh_beruf_num beh_berufstellg_num beh_ausbildung_num ///
 beh_tag_entg beh_ao_gem_num beh_pers_gr_num beh_w93_num beh_w03_num beh_w08_num  using  $beh\\$beh_Bez, clear


 ren prs_id id
 ren beh_* *
 ren *_num *
 ren sex_id sex
  
 drop if betnr==.
 drop if id == .
 drop if tag_entg < 10
 drop if tag_entg == .
 
 
forv i = 1999/2010{

preserve

//Nur Spells zum 30.6. des Jahres i behalten

keep if beg_dat <= d(30Jun`i') & end_dat >= d(30Jun`i')  
 
// Nur den bestbezahlten Spell behalten, ansonsten duplicates drop
d tag_entg   // wenn storage type nicht double  sondern long, bitte beim nächsten Befehl anpassen! (egen long)
bys id betnr: egen double max_lohn = max(tag_entg)	
compare  tag_entg max_lohn  // wenn hier nicht massive Übereinstimmung, kann irgendwas nicht stimmen!
keep if  tag_entg==max_lohn
drop max_lohn

duplicates drop id betnr, force

 // Vorerst nur fr das Sample von 90,000 Betrieben!
 merge m:1 betnr using $data/betnrs_send_hire_2_20151002
 keep if _merge==3
 drop _merge
 
 gen byte male = sex ==1
 drop sex 
 
 keep if pers_gr==101
 drop pers_gr
 
 // Wir behalten (Fach-)Arbeiter, Angestellte, Meister/Poliere, nicht aber Azubis, auerdem nur Vollzeit
 keep if berufstellg>0 & berufstellg<5
 qui tab berufstellg, gen(d_berufstellg) 
 gen beruf_2 = int(beruf/10)
 qui tab beruf_2, gen(d_beruf_2)

// Wir behalten alle Ausbildungsgruppen und Berufe
  
 gen d_ausb1 =  ausbildung==1 | ausbildung==7	// kein Abschluss oder unbekannt (unbekannt haben mit Abstand den niedrigsten Lohn)
 gen d_ausb2 =  ausbildung==2 | ausbildung==3 | ausbildung==4	// Berufsausbildungung, Abi, oder Berufsausbildungung und Abi
 gen d_ausb3 =  ausbildung==5 | ausbildung==6 // FH oder Uni
   
 gen gebjahr = year(geb_dat)
 gen age = `i' - gebjahr
 gen age_sq = age^2

 su tag_entg, de
  
 // Lohnimputation
 
 //zunchst Vorbereitungen
  // WZ 2-Steller
   
 if `i'<2003 {
 gen wz_2 = int(w93 /1000)
 }
 if `i'>2002 & `i' <2009 {
 gen wz_2 = int(w03 /1000)
 }
 if `i'>2008 {
 gen wz_2 = int(w08 /1000)
 }
   
 // WZ 3-Steller (wird unten gebraucht)

 if `i'<2003 {
 gen wz_3 = int(w93 /100)
 }
 if `i'>2002 & `i' <2009 {
 gen wz_3 = int(w03 /100)
 }
 if `i'>2008 {
 gen wz_3 = int(w08 /100)
 }
 
 qui tab wz_2, gen(d_wz_2)
 drop wz_2 
	
 // Kosfeld/Werner AMR
  gen arb_kr = int(ao_gem / 1000)
  drop ao_gem
  merge m:1 arb_kr using $data/AMR_Kreise_2011_Kosfeld_Werner_bearbeitet, keepusing(ram)
  drop if _merge~=3
  qui tab ram, gen(d_ram)
  drop _merge  ram
  ren arb_kr kreis

  gen jahr = `i'

//Jetzt eigentliche Lohnimputation  
 do $prog\\$DO_Bez_2

 gen lnw_i = ln(w_imp)
 
 keep id betnr tag_entg w_imp lnw_i male d_ausb*  age*  d_berufstellg*  d_beruf_2*   wz_3  ost

 saveold $data/temp_lohnimp_`i', replace
 
 restore
 
 }
 
 cap log close
  
 //=================================================================================================== 

 
  log using $log/Betriebseffekt_Teil2_$date, replace
 
 // Jetzt eigentliche Ermittlung der Betriebs-FE
   
  forval i = 1999/2010{
   
      
  use $data/temp_lohnimp_`i', clear
  
  bys betnr: egen zeit = seq()
  xtset betnr zeit    
  	 	  
  xtreg lnw_i male d_ausb*  age  age_sq   d_berufstellg*  d_beruf_2* , fe
  // wz fliegt raus wg. Betriebs-FE, ebenso ost bzw. d_ram* (innerhalb eines Jahres bzw. Stichtags zieht kein Betrieb um)
  
  predict fe_betrieb_xtreg, u
 
  // Individuen-Residuum - Abweichung des Individuums von gleich qualifizierten Mitarbeitern desselben Betriebs
  predict fe_indiv, e
 
  preserve
	keep id betnr ost male tag_entg w_imp fe_indiv 

	// Normalisierung des Lohnresiduums
	bys betnr: egen sd_fe = sd(fe_indiv)
	gen fe_indiv_stand = fe_indiv / sd_fe

	ren fe_indiv fe_indiv_raw
	ren fe_indiv_stand fe_indiv
	drop sd_fe

	// Es gibt ein paar wenige (!) missings - kann nur sein, weil nur eine Beob. pro Betrieb
	// Dann mssen wir stattdessen das "rohe" Residuum nehmen (?)
	replace fe_indiv = fe_indiv_raw if fe_indiv==.

	gen jahr = `i'
 
	saveold $data/Indiv_Lohneffekte_`i', replace 
  restore

 /* Jetzt betriebsfixe Effekte*/
 // Bereinigung um Industrieeffekte

  keep betnr wz_3  fe_betrieb_xtreg
  duplicates drop 
  qui tab wz_3, gen(d_wz_3)
 
  reg fe_betrieb_xtreg d_wz_3*
  predict fe_betrieb_resid, r
 
  drop d_wz_3*
  
  // Drfte eigtl. nicht sein, aber es gibt ein paar Duplikate  (sehr wenige, d.h. 5 von 2 Mio.), die nachher stren wrden
  duplicates drop betnr, force
   
  saveold $data/Betriebseffekte_`i', replace 
  }
 
 set rmsg off
 
 log close
