cap log close
log using "$log_files_path/lohnposition", replace

cd $path_project


/* 1. Step: Deflate normalised worker wage position (see Appendix B) to 2010 price levels */

forvalues i = 1999/2010{
use  Datensatz_IEB/Data-files_Ende/beh_20151201/Indiv_Lohneffekte_`i' , clear
keep id betnr w_imp fe_indiv jahr
duplicates drop id betnr,force
merge m:1 jahr using $path_project/Sonstige_Daten/Deflation_1975_2010, keepusing(defl_faktor)
drop if _merge==2
drop _merge
	
foreach var of varlist w_imp fe_indiv* {
replace `var' = `var'*defl_faktor
}
	
drop defl_faktor
save $data_files_path/Indiv_Lohneffekte_Neu_`i' , replace
}



/* Step 2: Merge person fixed wage effects and imputed wages (imputation necessary due to censoring at the social security contribution limit) */
forval i = 2002/2010{


use $data_files_path/neuzugänge_betriebswechsler_clean_bad_chk_fe_t1_`i', clear

/* Step 2a: for sending establishment  */
ren betnr betnr_rec
rename betnr_beschvor_`i'0101 betnr


// employed in relevant EP establishment on Jan 1 year `i' 
// (1) employed in sending establishment on Jun 30 year `i'-1
local yearbef = `i'-1 
merge 1:1 id betnr using "$data_files_path/Indiv_Lohneffekte_Neu_`yearbef'"
drop if _merge == 2
drop _merge
rename fe_indiv fe_indiv_1
rename w_imp w_imp_1


// (2) not employed in sending establishment on Jun 30 year `i'-1, but on Jun 30 year `i'-2
local yearbef2 = `i'-2
merge 1:1 id betnr using "$data_files_path/Indiv_Lohneffekte_Neu_`yearbef2'"
drop if _merge == 2
drop _merge
rename fe_indiv fe_indiv_2
ren w_imp w_imp_2


// (3) not employed in sending establishment on Jun 30 year `i'-1 or year `i'-2 but on Jun 30 year `i'-3
local yearbef3 = `i'-3
merge 1:1 id betnr using "$data_files_path/Indiv_Lohneffekte_Neu_`yearbef3'"
drop if _merge == 2
drop _merge
rename fe_indiv fe_indiv_3
ren w_imp w_imp_3


gen fe_indiv = fe_indiv_2
replace fe_indiv = fe_indiv_1 if fe_indiv == .
replace fe_indiv = fe_indiv_3 if fe_indiv == .

gen w_imp = w_imp_2
replace w_imp = w_imp_1 if w_imp == .
replace w_imp = w_imp_3 if w_imp == .


drop w_imp_* fe_indiv_* 
rename betnr betnr_vor_beschspell_`i'0101
ren  betnr_rec betnr


/* Step 2b: for sending establishment  */

ren fe_indiv fe_indiv_send
ren w_imp w_imp_send


merge 1:1 id betnr using "$data_files_path/Indiv_Lohneffekte_Neu_`i'", keepusing(fe_indiv w_imp)
drop if _merge==2
drop _merge

ren fe_indiv fe_indiv_hire
ren w_imp w_imp_hire

/* Step 3: deflating wage for inflows with no wage information from wage regression available (only for those below social security contribution limit) */
gen byte ost = arb_kr>=11000

//social security contribution limit
gen limit=.
replace limit = 140 if jahr==1999 & ost==0
replace limit = 141 if jahr==2000 & ost==0 
replace limit = 143 if jahr==2001 & ost==0
replace limit = 145 if jahr==2002 & ost==0
replace limit = 165 if jahr==2003 & ost==0
replace limit = 166 if jahr==2004 & ost==0
replace limit = 168 if jahr==2005 & ost==0
replace limit = 170 if jahr==2006 & ost==0
replace limit = 170 if jahr==2007 & ost==0
replace limit = 171 if jahr==2008 & ost==0
replace limit = 175 if jahr==2009 & ost==0
replace limit = 178 if jahr==2010 & ost==0

replace limit = 118 if jahr==1999 & ost==1
replace limit = 116 if jahr==2000 & ost==1
replace limit = 120 if jahr==2001 & ost==1
replace limit = 120 if jahr==2002 & ost==1
replace limit = 137 if jahr==2003 & ost==1
replace limit = 140 if jahr==2004 & ost==1
replace limit = 142 if jahr==2005 & ost==1
replace limit = 142 if jahr==2006 & ost==1
replace limit = 147 if jahr==2007 & ost==1
replace limit = 145 if jahr==2008 & ost==1
replace limit = 147 if jahr==2009 & ost==1
replace limit = 150 if jahr==2010 & ost==1

//deflation factor - hiring establishment
merge m:1 jahr using $path_project/Sonstige_Daten/Deflation_1975_2010, keepusing(defl_faktor)
drop if _merge==2
drop _merge
ren defl_faktor defl_f_i   

//deflation factor - sending establishment
replace jahr = jahr-2
merge m:1 jahr using $path_project/Sonstige_Daten/Deflation_1975_2010, keepusing(defl_faktor)
drop if _merge==2
drop _merge
replace jahr = jahr+2  

//deflate
replace b_entg = b_entg*defl_f_i
replace b_entg_beschvor_`i'0101 = b_entg_beschvor_`i'0101 * defl_faktor
drop defl*
	
replace w_imp_hire = b_entg if w_imp_hire==. & b_entg <= (limit+3)	
replace w_imp_send = b_entg_beschvor_`i'0101  if w_imp_send==. &  b_entg_beschvor_`i'0101 <= (limit+3)	
	
drop ost limit
drop  b_entg*

save $data_files_path/neuzugänge_betriebswechsler_clean_bad_chk_fe_wagepos_t1_`i', replace
}

forvalues i = 1999/2010{
erase $data_files_path/Indiv_Lohneffekte_Neu_`i'.dta
}
log close
